"""
NOTE: this is a failure...
I really have to manually upload new datasets, this command line bull isn't gonna work well
"""

from subprocess import Popen,PIPE

def run_command(command = 'dir'):
    pipe = Popen(command,stdout=PIPE,stderr=PIPE)    

    ret = []
    while True:         
        line = pipe.stdout.readline()
        if line:            
            ret.append(line.decode('utf8'))
        if not line:
            break

    return "".join(ret).replace("[\n\r]+","\n")

#run_command(["osf","ls"])


__all__ = [
    'variable_dir',
    'figure_dir',
    'modules'
]

import os
from pathlib import Path

variable_dir = Path(os.environ['VARDIR'])

# more local stuff
notebook_dir = Path(os.environ['NBDIR']).parent
figure_dir = notebook_dir.joinpath('figures')
table_dir = notebook_dir.joinpath('tables')


for d in [figure_dir,table_dir,variable_dir]:
    if not d.exists():
        print("Creating directory: %s" % d)
        d.mkdir()


if __name__ == '__main__':
    import sys
    print(sys.argv)
else:
    from IPython.core.display import display, HTML, Markdown, Image
    from collections import Counter, defaultdict
    from random import sample, shuffle
    from itertools import chain

    from tabulate import tabulate
    import re

    from pathlib import Path
    from os.path import dirname, join
    BASEDIR = dirname(__file__)

    from csv import reader as creader

    import networkx as nx
    import pandas as pd
    import seaborn as sns


    import matplotlib.pyplot as plt
    plt.style.use('seaborn-whitegrid')
    import numpy as np

    from logzero import logger


    from .exceptions import *



    from . import env
    from .utility import *

    # this uses some imports from here...
    from .datastore_cnts import *
    #from .datastore_sql import *
    from .code_sharing import *
    from . import viz
    #from .meta_notebook import *

    #from .knowknow_base import  *
    #from .archive import *


import os
from random import randint
from unittest import TestCase
import knowknow.utility as knowknow


class Test(TestCase):
    def test_comb(self):
        self.assertEqual(knowknow.comb('q.w.e', 'e.r.t'), 'e.q.r.t.w')

    def test_gen_tuple_template(self):
        template = knowknow.gen_tuple_template(tuple('qwer'))
        self.assertEqual(template._fields, tuple('qwer'))
        self.assertEqual(template.__name__, '_'.join('qwer'))

    def test_make_cross(self):
        k___v = dict(zip('qwert', '12345'))
        namedtuple = knowknow.make_cross(k___v)
        old_cross = knowknow.make_cross_kwargs(k___v)
        for k, v in k___v.items():
            self.assertEqual(v, namedtuple.__getattribute__(k))
            self.assertEqual(v, old_cross.__getattribute__(k))

    def test_download_file(self):
        url = 'http://example.com/'
        outfn = 'a.test'
        knowknow.download_file(url, outfn)

        avi_url = 'https://file-examples-com.github.io/uploads/2018/04/file_example_AVI_1920_2_3MG.avi'
        knowknow.download_file(avi_url, outfn)
        self.assertAlmostEqual(2.3, os.path.getsize(outfn) / 2 ** 20, delta=0.2)

    def test_named_tupelize(self):
        ctypes = 'q.w.e.r'
        d = {tuple(randint(1, 100) for _ in range(len(ctypes))): 'value' for _ in range(4)}
        tupelized = knowknow.named_tupelize(d, ctypes)
        self.assertEqual(len(d), len(tupelized))
        for key in d:
            self.assertTrue(
                knowknow.make_cross(dict(zip(sorted(ctypes.split('.')), key))) in tupelized)



import setuptools
from setuptools.command.install import install

with open("README.md", "r") as fh:
    long_description = fh.read()
    
class InstallWrapper(install):
    """Provides a install wrapper to handle set-up of dependencies."""
    def run(self):
        install.run(self)
        self.setup_nltk()

    def setup_nltk(self):
        import nltk
        nltk.download('stopwords')

setuptools.setup(
    name="knowknow-amcgail", # Replace with your own username
    version="0.2.20",
    author="Alec McGail",
    author_email="amcgail2@gmail.com",
    description="Analyzing the evolution of ideas using citation analysis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/amcgail/knowknow",
    packages=setuptools.find_packages(),
    package_data={
        "knowknow":[
            #"analyses/*",
            #"creating variables/*",
            #"external-data/*",
            #"utilities/*",
            #"writeups/*",
            "*.*"
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        "colour>=0.1.5",
        "cycler>=0.10.0",
        "editdistance>=0.5.3",
        "ipython>=7.14.0",
        "jupyter>=1.0.0",
        "jupyterlab>=2.1.2",
        "lxml>=4.4.1",
        "matplotlib>=3.2.1",
        "nameparser>=1.0.6",
        "networkx>=2.3",
        "nltk>=3.5",
        "numpy>=1.18.4",
        "pandas>=1.0.3",
        "PyYAML>=5.3.1",
        "scikit-learn>=0.23.0",
        "scipy>=1.4.1",
        "seaborn>=0.10.1",
        "six>=1.14.0",
        "sklearn>=0.0",
        "statsmodels>=0.11.1",
        "string-grouper>=0.1.0",
        "tabulate>=0.8.7",
    ],
    cmdclass={'install': InstallWrapper},
)


__all__ = [
    'require'
]

modules = {
    'citation-deaths': "G:/My Drive/2020 ORGANISATION/1. PROJECTS/qualitative analysis of literature/110 CITATION ANALYSIS/010 analyses/bundle 101 - citation deaths reboot 10-2020",
    'wos-counter': "G:/My Drive/2020 ORGANISATION/1. PROJECTS/qualitative analysis of literature/110 CITATION ANALYSIS/010 analyses/bundle 102 - creating wos database",
    'stats': "G:/My Drive/2020 ORGANISATION/1. PROJECTS/qualitative analysis of literature/110 CITATION ANALYSIS/010 analyses/bundle 103 - various statistics"
    #'summary-stats': ""
}

require('amcgail/citation-deaths', '.')

mod_cache = {}

def require(where, what):
    wsp = what.split("/")
    space = wsp[0]

    from pathlib import Path

    if space in modules:
        spacefn = Path(modules[space])
    elif


    if len(wsp) == 2:
        # get it from __init__
        modfn = spacefn.joinpath("__init__.py")

    elif len(wsp) == 3:
        # get it from file within
        modfn = spacefn.joinpath("%s.py" % wsp[1])


    if modfn in mod_cache:
        mod = mod_cache[modfn]
    else:
        from runpy import run_path
        mod = run_path( modfn )

        if '__all__' in mod:
            mod = {
                k: v for k,v in mod.items() if k in mod['__all__']
            }

        mod_cache[modfn] = mod

    return mod[wsp[-1]]